@@ -1,6 +1,7 @@
 import json
 import os
-from typing import Any, Union
+import random
+from typing import Any, Union, Optional
 
 
 def cls() -> None:
@@ -8,6 +9,15 @@ def cls() -> None:
   os.system('cls' if os.name == 'nt' else 'clear')
 
 
+def log_error(msg: str, exception: Exception):
+  """
+  Mostra mensagem de error com a exception
+  :param msg: mensagem
+  :param exception: Exception
+  """
+  print(f'\033[31m[ERROR]\033[m{msg} | {exception} | {exception.__class__.__name__}')
+
+
 def is_a_valid_id(id_: Union[str, int]) -> bool:
   """
   Verifica se o número ou a string recebida é um número válido.
@@ -30,6 +40,21 @@ def is_a_valid_username(string: str) -> bool:
   return True if 2 <= len(string) <= 15 else False
 
 
+def random_from_list(arr: list[str]) -> Optional[str]:
+  """
+  Seleciona um item aleatório da lista.
+  :param arr: lista de itens.
+  :return: um item aleatório da lista | None
+  """
+  try:
+    return random.choice(arr)
+  except IndexError:
+    return None
+  except Exception as e:
+    log_error('Random from list', e)
+    return None
+
+
 def create_default_files() -> None:
   """Criar o config.json padrão"""
   if not os.path.exists('config.json'):
@@ -38,7 +63,8 @@ def create_default_files() -> None:
       "validator": "check",
       "autoStop": False,
       "autoReady": True,
-      "avatar": 0
+      "avatar": 0,
+      "useEquivalence": True
     }
     with open('config.json', 'w') as config_file:
       json.dump(data, config_file, indent=2)
@@ -58,17 +84,29 @@ def get_config_setting(setting: str) -> Any:
     print(f'Failed get json setting. Error: {e}')
 
 
+def invert_setting(data: dict, setting: str, msg: str) -> None:
+  """
+  Inverte uma configuração booleana
+  :param data: python dictionary
+  :param setting: chave/nome
+  :param msg: mensagem/prefixo
+  """
+  data[setting] = False if data[setting] else True
+  print(msg, "Habilitado" if data[setting] else "Desabilitado")
+
+
 def open_config_menu() -> None:
   """Abre um menu de configurações para o config.json"""
   with open('config.json', 'r+') as config_file:
     data = json.load(config_file)
     while True:
-      print(f'1 - Mudar username [Atual: {data["username"]}]\n',
-            f'2 - Alterar o validador [Atual: {data["validator"]}]\n',
-            f'3 - Auto Stop [Status: {data["autoStop"]}]\n',
-            f'4 - Auto Ready [Status: {data["autoReady"]}]\n',
-            f'5 - Mudar avatar [Atual: {data["avatar"]}]\n',
-            '0 - Voltar.')
+      print(f'1 - Mudar username [Atual: {data["username"]}]\n'
+            f'2 - Alterar o validador [Atual: {data["validator"]}]\n'
+            f'3 - Auto Stop [Status: {data["autoStop"]}]\n'
+            f'4 - Auto Ready [Status: {data["autoReady"]}]\n'
+            f'5 - Mudar avatar [Atual: {data["avatar"]}]\n'
+            f'6 - Equivalência de categorias [Atual: {data["useEquivalence"]}]\n'
+            '0 - Voltar')
       option_to_config = input('> ')
       cls()
 
@@ -82,10 +120,10 @@ def open_config_menu() -> None:
             print('Seu username/nick deve possuir entre 2 e 15 caracteres.')
 
       elif option_to_config == '2':
-        validator_change = int(input('1 - Rápido (Apenas confirma.)\n'
-                                     '2 - Negar - (Invalidará todas as respostas inclusive as suas.)\n'
-                                     '3 - Aceitar - (Validará todas as respostas inclusive as erradas.)\n'
-                                     '4 - Avaliar - (Avaliará as respostas com base no dicionario e negará as outras.)\n'
+        validator_change = int(input('1 - Rápido - Apenas confirma.\n'
+                                     '2 - Negar - Invalidará todas as respostas inclusive as suas.\n'
+                                     '3 - Aceitar - Validará todas as respostas inclusive as erradas.\n'
+                                     '4 - Avaliar - Avaliará as respostas com base no dicionario e negará as outras.\n'
                                      '5 - Não fazer nada.\n'
                                      '> '))
 
@@ -105,21 +143,14 @@ def open_config_menu() -> None:
           data['validator'] = 'null'
           print('Validador alterado para não fazer nada.\n')
 
-      elif option_to_config == '3':
-        if data['autoStop']:
-          data['autoStop'] = False
-          print('Auto Stop Desabilitado.\n')
-        else:
-          data['autoStop'] = True
-          print('Auto Stop Habilitado.\n')
-
-      elif option_to_config == '4':
-        if data['autoReady']:
-          data['autoReady'] = False
-          print('Auto Ready Desabilitado.\n')
-        else:
-          data['autoReady'] = True
-          print('Auto Ready Habilitado.\n')
+      elif option_to_config in ['3', '4', '6']:
+        settings = {
+          3: {'setting': 'autoStop', 'msg': 'Auto Stop'},
+          4: {'setting': 'autoReady', 'msg': 'Auto Ready'},
+          6: {'setting': 'useEquivalence', 'msg': 'Equivalência'}
+        }
+        option_to_config = int(option_to_config)
+        invert_setting(data, settings[option_to_config]['setting'], settings[option_to_config]['msg'])
 
       elif option_to_config == '5':
         while True:
